__version__ = "0.0.1"

# 可外部调用的包的函数
from eqlog.log import *
